# Copyright 2018 miruka
# This file is part of whratio, licensed under LGPLv3.

"Calculate integer and decimal aspect ratio for dimensions."

__pkg_name__ = "whratio"
__version__  = "3.1.0"
__status__   = "Production"

__author__   = "miruka"
__email__    = "miruka@disroot.org"

__license__  = "LGPLv3"
